@@ -142,7 +142,7 @@ def _insert_jos_users_password(db, userid, pw):
 	db.execQuery(sql, data)
 
 
-def _add_ldap_user(username, gecos, password, uidNumber, homeDir, loginShell):
+def _add_ldap_user(username, gecos, password, uidNumber, homeDir, loginShell, gid, gidNumber):
 
 	# get ldapManagerUserDN and PW
 	
@@ -170,7 +170,8 @@ def _add_ldap_user(username, gecos, password, uidNumber, homeDir, loginShell):
 	attrs['loginShell'] = loginShell
 	
 	# TODO: grab this from the com_members component parm field
-	attrs['gidNumber'] = "100"
+	attrs['gidNumber'] = str(gidNumber)
+	#attrs['gid'] = gid
 	
 	print "add ldap user dn: " + dn
 
@@ -222,10 +223,14 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
 		firstName = fullName[0]
 		middleName = ""
 		lastName = fullName[1]
-	else:
+	elif len(fullName) == 1:
 		firstName = fullName[0]
 		middleName = ""
 		lastName = ""
+	else:
+		firstName = ""
+		middleName = ""
+		lastName = ""
 	
 
 	# usually homeDir will be blank, but not always
@@ -236,6 +241,12 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
 	if pwdisabled: 
 		pw = "*"
 
+	# create linux group for user named same as username (need group insert here for xprofiles addition below)
+	if createGroup:
+		gidNumber = hubzero.utilities.group._insert_jos_xgroups(db, username, username + " group")	
+		gid = username # group name same as user
+
+
 	userID = _insert_jos_users(db, joomlauserid, fullName, username, email, pw, joomlagid, joomlagidNumber)
 	aroID = _insert_jos_core_acl_aro(db, userID, fullName)
 	_insert_jos_core_acl_groups_aro_map(db, joomlagidNumber, aroID)
@@ -243,19 +254,17 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
 	_insert_jos_users_password(db, userID, pw)
 
 
-	# create linux group for user named same as username
+	# create linux group for user named same as username (need xgroups insert here because we need userid)
 	if createGroup:
 
-		gidNumber = hubzero.utilities.group._insert_jos_xgroups(db, username, username + " group")	
 		hubzero.utilities.group._insert_jos_xgroups_members(db, gidNumber, userID)
-
 		hubzero.utilities.group._add_ldap_group(username, username + " group", gidNumber)
 	else:
 		gidNumber = 100 # default to the users group
 		
 	
 	if not skipldap:
-		_add_ldap_user(username, gecos, pw, userID, homeDir, loginShell)
+		_add_ldap_user(username, gecos, pw, userID, homeDir, loginShell, gid, gidNumber)
 
 
 	# create home directory
